/*  Last edited: Mar 16 17:36 1997 (birney) */


#ifndef DYNAMITEHELPERHEADERFILE
#define DYNAMITEHELPERHEADERFILE


/*** this file includes all the correct files
  for libdyn linking ***/


#include "packaln.h"
#include "basematrix.h"
#include "dpenvelope.h"

#include "sequence.h"
#include "proteindb.h"
#include "database.h"
#include "hscore.h"
#include "histogram.h"
#include "aln.h"
#include "linesubs.h"
#include "complexsequence.h"
#include "complexevalset.h"
#include "alnconvert.h"
#include "alnrange.h"
#include "compmat.h"
#include "dnamatrix.h"
#include "protein.h"
#include "dna.h"

#include "btcanvas.h"
#include "asciibtcanvas.h"

#include "dynlibcross.h"
#endif






